@@ -66,60 +66,71 @@ class random:
 #javacode에 추가해준다.
 def define_auto(code):
     var_name = code.split("=")[0]
+    global addition_list
     global var_dict_type
     global var_list
     global var_dict
     global javacode
     m = ''
+    code1 = code.split(".")[-1]
+    if code1.__contains__("size"):
+        code1 = code.split(".")[-2]
+    elif code1.__contains__("get("):
+        code1 = code
+    code = code1
+    type_Var = ""
+    code = code.replace(" ","")
+    if code.__contains__('getPlayer') or code.__contains__('sender') or code.__contains__('getEntity'):
+        type_Var = "Player"
+        m = 'public Player '+var_name+";\n"
+        addition_list.append("org.bukkit.entity.Player")
+    elif code.__contains__('getWorld'):
+        type_Var = "World"
+        m = 'public World '+var_name+";\n"
+        addition_list.append("org.bukkit.World")
+    elif code.__contains__('getItemInHand'):
+        type_Var = "ItemStack"
+        m = 'public ItemStack '+var_name+" = new ItemStack();\n"
+    elif code.__contains__('getName') or code.__contains__('toString'):
+        type_Var = "String"
+        m = 'public String '+var_name+";\n"
+    elif code.__contains__('getInventory'):
+        type_Var = "Inventory"
+        m = 'public Inventory '+var_name+";\n"
+        addition_list.append("org.bukkit.inventory.Inventory")
+    elif code.__contains__('getLocation'):
+        type_Var = "Location"
+        m = 'public Location '+var_name+";\n"
+        addition_list.append("org.bukkit.Location")
+    elif code.__contains__('getX') or code.__contains__('getY') or code.__contains__('getZ') or code.__contains__("randint"):
+        m = 'public Integer '+var_name+";\n"
+        type_Var = "Integar"
+    elif code.__contains__('getBlock'):
+        type_Var = "Block"
+        m = 'public Block '+var_name+" = new Block();\n"
+        addition_list.append("org.bukkit.block.Block")
+    elif code.__contains__('getMaterial'):
+        m = 'public Material '+var_name+";\n"
+        type_Var = "Material"
+        addition_list.append("org.bukkit.Material")
+    elif code.__contains__(".get("):
+        code = code.replace(".get("," ")
+        code = code.replace(")"," ")
+        code = code.replace("="," ")
+        code1 = code.split(" ")[0]
+        code2 = code.split(" ")[1]
+        var_name = code1
+        m = 'public '+str(var_dict.get(code2))+' '+code1+";\n"
+        type_Var = str(var_dict.get(code2))
+    type_Var2 = type_Var.lower()
+    var_name =var_name.replace(" ","")
+    if var_list.__contains__(var_name):
+        raise Exception("you already defined in other type")
     if not var_list.__contains__(var_name):
-        var_list.append(var_name)
-        code1 = code.split(".")[-1]
-        if code1.__contains__("size"):
-            code1 = code.split(".")[-2]
-        elif code1.__contains__("get("):
-            code1 = code
-        code = code1
-        type_Var = ""
-        code = code.replace(" ","")
-        if code.__contains__('getPlayer') or code.__contains__('sender'):
-            type_Var = "Player"
-            m = 'public Player '+var_name+";\n"
-        elif code.__contains__('getWorld'):
-            type_Var = "World"
-            m = 'public World '+var_name+";\n"
-        elif code.__contains__('getItemInHand'):
-            type_Var = "ItemStack"
-            m = 'public ItemStack '+var_name+" = new ItemStack();\n"
-        elif code.__contains__('getName') or code.__contains__('toString'):
-            type_Var = "String"
-            m = 'public String '+var_name+";\n"
-        elif code.__contains__('getInventory'):
-            type_Var = "Inventory"
-            m = 'public Inventory '+var_name+";\n"
-        elif code.__contains__('getLocation'):
-            type_Var = "Location"
-            m = 'public Location '+var_name+";\n"
-        elif code.__contains__('getX') or code.__contains__('getY') or code.__contains__('getZ') or code.__contains__("randint"):
-            m = 'public Integer '+var_name+";\n"
-            type_Var = "Integar"
-        elif code.__contains__('getBlock'):
-            type_Var = "Block"
-            m = 'public Block '+var_name+" = new Block();;\n"
-        elif code.__contains__('getMaterial'):
-            m = 'public Material '+var_name+";\n"
-            type_Var = "Material"
-        elif code.__contains__(".get("):
-            code = code.replace(".get("," ")
-            code = code.replace(")"," ")
-            code = code.replace("="," ")
-            code1 = code.split(" ")[0]
-            code2 = code.split(" ")[1]
-            var_name = code1
-            m = 'public '+str(var_dict.get(code2))+' '+code1+";\n"
-            type_Var = var_dict.get(code2)
         var_name = var_name.replace(" ","")
         var_dict[var_name] = (type_Var)
         javacode = javacode.replace("implements Listener{\n","implements Listener{\n"+'    '+m)
+        var_list.append(var_name)
     return javacode
 class space:
     def forfinish(code):
@@ -207,9 +218,10 @@ def print(message):
 class Player:
     def __init__(self):
         global addition_list
-        if not addition_list.__contains__('org.bukkit.entity.Player'):
-            addition_list.append('org.bukkit.entity.Player')
         global check_list
+        if check_list.__contains__("init"):
+            if not addition_list.__contains__('org.bukkit.entity.Player'):
+                addition_list.append('org.bukkit.entity.Player')
         self.type = "player"
         check_list.append("define")
     def setHealth(self,value):
@@ -247,16 +259,36 @@ class Player:
 class ArrayList:
     def __init__(self,typeof):
         global addition_list
-        if not addition_list.__contains__('java.util.ArrayList'):
-            addition_list.append('java.util.ArrayList')
         global check_list
+        if check_list.__contains__("init"):
+            if not addition_list.__contains__('java.util.ArrayList'):
+                addition_list.append('java.util.ArrayList')
         global var_dict_type
         check_list.append("define")
         self.type = typeof
     def add(self,something):
+        import inspect
+        frame = inspect.stack()[1]
+        module = inspect.getmodule(frame[0])
+        filename = module.__file__
+        g = str(type(something))
+        if g.__contains__("."):
+            g = g.split(".")[-1]
+            g = g.split("'")[0]
+        else:
+            g = g.split("'")[1]
+            g = g.split("'")[0]
+        g = g.lower()
+        if g != self.type:
+            if not(type(something) == "str" and self.type == "string"):
+                if not(type(something) == "int" and self.type == "Integar"):
+                    raise Exception("ArrayList type and input value's type isn't same |"+"ArrayList type : "+g+" | input value type : "+str(self.type)+" |")
         global check_list    
         check_list.append("activity")
     def get(self,index):
+        g = str(type(index))
+        if g.__contains__("."):
+            raise Exception("must be int")
         global material1
         global player1
         if self.type == "player":
@@ -270,8 +302,17 @@ class ArrayList:
         frame = inspect.stack()[1]
         module = inspect.getmodule(frame[0])
         filename = module.__file__
-        if self.type != type(something):
-            raise Exception('compare thing type have to be same as type of list '+filename+'", line '+str(whenerror)+',')
+        g = str(type(something))
+        if g.__contains__("."):
+            g = g.split(".")[-1]
+            g = g.split("'")[0]
+        else:
+            g = g.split("'")[1]
+            g = g.split("'")[0]
+        g = g.lower()
+        if self.type != g:
+            if not self.type == "string" and type(something) == "str":
+                raise Exception('compare thing type have to be same as type of list '+filename+'", line '+str(whenerror)+',')
 class String:
     def __init__(self):
         global check_list
@@ -329,9 +370,10 @@ def Event():
 class Location:
     def __init__(self):
         global addition_list
-        if not addition_list.__contains__('org.bukkit.Location'):
-            addition_list.append('org.bukkit.Location')
         global check_list
+        if check_list.__contains__("init"):
+            if not addition_list.__contains__('org.bukkit.Location'):
+                addition_list.append('org.bukkit.Location')
         check_list.append("define")
     def getBlock(self):
         global bc1
@@ -385,17 +427,19 @@ class Inventory:
         global check_list
         check_list.append("define")
         global addition_list
-        if not addition_list.__contains__('org.bukkit.inventory.Inventory'):
-            addition_list.append('org.bukkit.inventory.Inventory')
+        if check_list.__contains__("init"):
+            if not addition_list.__contains__('org.bukkit.inventory.Inventory'):
+                addition_list.append('org.bukkit.inventory.Inventory')
     def addItem(self,itemStack):
         global check_list
         check_list.append("activity")
 class ItemStack:
     def __init__(self):
         global addition_list
-        if not addition_list.__contains__('org.bukkit.inventory.ItemStack'):
-            addition_list.append('org.bukkit.inventory.ItemStack')
         global check_list
+        if check_list.__contains__("init"):
+            if not addition_list.__contains__('org.bukkit.inventory.ItemStack'):
+                addition_list.append('org.bukkit.inventory.ItemStack')
         check_list.append("define")
     def setMaterial(self,something):
         global check_list
@@ -416,9 +460,10 @@ class World:
     def __init__(self):
         self.type = "world"
         global addition_list
-        if not addition_list.__contains__('org.bukkit.World'):
-            addition_list.append('org.bukkit.World')
-        global check_list    
+        global check_list
+        if check_list.__contains__("init"):
+            if not addition_list.__contains__('org.bukkit.World'):
+                addition_list.append('org.bukkit.World')
         check_list.append("define")
     def setGameRule(self,gamerule,status):
         if not addition_list.__contains__('org.bukkit.GameRule'):
@@ -432,9 +477,10 @@ class Block:
     def __init__(self):
         self.type = "Block"
         global addition_list
-        if not addition_list.__contains__('org.bukkit.block.Block'):
-            addition_list.append('org.bukkit.block.Block')
-        global check_list    
+        global check_list
+        if check_list.__contains__("init"):
+            if not addition_list.__contains__('org.bukkit.block.Block'):
+                addition_list.append('org.bukkit.block.Block')    
         check_list.append("define")
     def getMaterial(self):
         global material1    
@@ -475,7 +521,7 @@ def when(*test):
         check_list.append("if")
         return True
     else:
-        repeat_var = 0
+        when_var = 0
         return False
 def repeat(*var_name):
     if len(var_name) ==1:
@@ -534,14 +580,18 @@ class Action:
     def __init__(self):
         self.type = "Action"
         global addition_list
-        if not addition_list.__contains__('org.bukkit.event.block.Action'):
-            addition_list.append('org.bukkit.event.block.Action')
-        global check_list    
+        global check_list
+        if check_list.__contains__("init"):
+            if not addition_list.__contains__('org.bukkit.event.block.Action'):
+                addition_list.append('org.bukkit.event.block.Action')
+            
         check_list.append("define")
 def player():
     return "player"
 def world():
     return "world"
+def string():
+    return "string"
 def Enable():
     return "Enable"
 def Disable():
@@ -807,6 +857,7 @@ def make(server,**setting):
                 code = code.replace("getWorld","getWorld()")
                 code = code.replace("getLocation","getLocation()")
                 code = code.replace("getInventory","getInventory()")
+                code = code.replace("getEntity","getEntity()")
                 code = code.replace("getBlock","getBlock()")
                 code = code.replace("getName","getName()")
                 code = code.replace("size","size()")
@@ -878,7 +929,9 @@ def make(server,**setting):
                 code1 = code1.replace('whileevent', '')
                 if not addition_list.__contains__('org.bukkit.event.EventHandler'):
                     addition_list.append('org.bukkit.event.EventHandler')
-                if code1.__contains__("Player") and not addition_list.__contains__('org.bukkit.event.player.'+code1):
+                if code1 == "PlayerDeathEvent" and not addition_list.__contains__('org.bukkit.event.player.'+code1):
+                    addition_list.append('org.bukkit.event.entity.'+code1)
+                elif code1.__contains__("Player") and not addition_list.__contains__('org.bukkit.event.player.'+code1):
                     addition_list.append('org.bukkit.event.player.'+code1)
                 elif code1.__contains__("Block") and not addition_list.__contains__('org.bukkit.event.block.'+code1):
                     addition_list.append('org.bukkit.event.block.'+code1)
@@ -1053,11 +1106,16 @@ def make(server,**setting):
             elif m == 'if':
                 del check_list[0] 
                 code = code.replace(" ","")
-                code = code.replace("when","")
+                code = code.replace("when(","(")
                 code = code.replace("while","if")
-                code = code.replace("not","!")
-                code = code.replace("==",".equals(")
-                code = code.replace(":",") {")
+                code = code.replace("__contains__","contains")
+                if code.__contains__("=="):
+                    code = code.replace("==",".equals(")
+                    
+                    code = code.replace("):",")):")
+                if code.__contains__("not"):
+                    code = code.replace("not","!")
+                code = code.replace(":"," {")
                 code =  code.replace("()","")
                 if not code.__contains__("!"):
                     code = code.replace(")))","))")
@@ -1089,7 +1147,6 @@ def make(server,**setting):
                 code = code.replace('):',"")
                 code = code.replace('"',"")
                 code = code.replace("'","")
-                sys.stdout.write(code)
                 name = 'onCommand'
                 command_contain +=1
                 java_space =1
@@ -1214,10 +1271,11 @@ class GameRule:
 class Material:
     def __init__(self):
         self.type = "Material"
-        global addition_list
-        if not addition_list.__contains__('org.bukkit.Material'):
-            addition_list.append('org.bukkit.Material')
         global check_list
+        global addition_list
+        if check_list.__contains__("init"):
+            if not addition_list.__contains__('org.bukkit.Material'):
+                addition_list.append('org.bukkit.Material')
         self.type = "material"    
         check_list.append("define")
     def toString(self):
